import type { Metadata } from "next";
import { Inter } from "next/font/google";

import { ThemeProvider } from "./ui/theme";
import { Toaster } from "@/components/ui/toaster";
import "./tailwind.css";
import Link from "next/link";
import { ComponentProps } from "react";
import { Send } from "lucide-react";
import Navlinks from "./ui/navLinks";

const inter = Inter({ subsets: ["latin"] });

export const metadata: Metadata = {
  title: "Subman",
  description: "A self-hosted literary submission tracker."
};



export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en">
      <body className={inter.className}>
        <ThemeProvider
          attribute="class"
          defaultTheme="system"
          enableSystem
          disableTransitionOnChange
        >
          <div id="layout-container" className="p-4 w-screen mt-6 flex justify-center">
            <div className="grid grid-cols-6 w-5/6">
              <div id="sidebar" className="col-start-1 col-end-2">
                <header className="">
                  <h1 className="font-black text-5xl antialiased inline">SubMan</h1>
                  <p className="font-bold text-m antialiased">The self-hosted literary submission tracker.</p>
                </header>
                <Navlinks />
              </div>
              <div className="col-start-2 col-span-full">
                {children}
              </div>
            </div>
          </div>
          <Toaster />
        </ThemeProvider>
      </body>
    </html >
  );
}
